@@ -75,6 +75,7 @@ def plot_agents_multigen(
     '''
 
     settings = settings or {}
+    agent_colors = settings.get('agent_colors', {})
     agents_key = settings.get('agents_key', 'agents')
     max_rows = settings.get('max_rows', 25)
     column_width = settings.get('column_width', 4)
@@ -240,7 +241,7 @@ def plot_agents_multigen(
                         plot_times = time_vec[time_idx:time_idx+n_times]
 
                         ax = port_axes[port_schema_path]
-                        ax.plot(plot_times, series)
+                        ax.plot(plot_times, series, color=agent_colors.get(agent_id, None))
 
     plt.subplots_adjust(wspace=0.2, hspace=0.2)
     if out_dir:
